<?php
/**
 * Linker is microtemplated, so this provides a library
 * of file required to make this and other parts of the system
 * work.
 */

if(!function_exists('file_put_contents'))
{
   function file_put_contents($name, $data)
   {
      $fp = fopen($name, 'w');
	  if($fp)
	  {
	     fwrite($fp, $data);
		 fclose($fp);
		 return true;
	  }
	  else
	  {
	     return false;
	  }
   }
}
 
/**
 * Fetches the output of a template.  Doesn't allow '../' or '..\' to
 * exist in the path and looks in the templates folder where common.php
 * is located. (It also will only open php files.)
 * @param array $v4r537 contains the variables to be passed to the template.
 * @param string $template Template file to use.
 * return string Contents generated by the template.
 */
function q_temp($v4r537, $t3mpl4t3)
{
   while(preg_match('/\.\.(\/|\\\\)/', $t3mpl4t3) )
   {
      $t3mpl4t3 = preg_replace('/\.\.(\/|\\\\)/', '', $t3mpl4t3);
   }
   $t3mpl4t3 .= '.php';
   
   extract($v4r537, EXTR_SKIP);
   ob_start();
   if(is_file(dirname(__FILE__)."/templates/{$t3mpl4t3}" ))
   {
      include(dirname(__FILE__)."/templates/{$t3mpl4t3}");
   }
   else
   {
      echo 'Template not found';
   }
   return ob_get_clean();
}

/**
 * Loads a set of links from our link store.
 * @param $name Name of linkset to load.
 * @return Mixed False on error, an array of links otherwise.
 */
function load_links($name)
{
   global $datalocation;
   $r = false;
   $s = basename($name);
   $s = "{$datalocation}/{$s}.ldat";
   if(is_file($s))
   {
      $r = unserialize(file_get_contents($s));
   }
   return $r;
}

/**
 * Deletes a set of links from our link store.
 * @param $name Name of linkset to delete.
 * @return bool False on error, an true on success
 */
function delete_links($name)
{
   global $datalocation;
   $r = true;
   $s = basename($name);
   $s = "{$datalocation}/{$s}.ldat";
   if(is_file($s))
   {
      $r = unlink($s);
   }
   return $r;
}

/**
 * Saves a set of links from our link store.
 * @param $name Name of linkset to save.
 * @param $links Array of links to set.
 * @return false on error, true on success.
 */
function save_links($name, $data)
{
   global $datalocation;
   $r = false;
   $s = basename($name);
   $s = "{$datalocation}/{$s}.ldat";
   $tosave = serialize($data);
   return file_put_contents($s, $tosave);
}

/**
 * Internal function to remove ldat extensions.
 */
function _rem_ext($dit)
{
   return preg_replace('/\.ldat$/', '', $dit);
}
/*Fushigi Yuugi OST*/

/**
 * List available linksets.
 * @return array of linksets currently on the system.
 */
function list_linksets()
{
   global $datalocation;
   $cd = getcwd();
   chdir($datalocation);
   $sets = glob('*.ldat');
   $sets = array_map('_rem_ext', $sets);
   chdir($cd);
   return $sets;
}